@@ -111,14 +111,14 @@ struct tftphdr {
  *****************************************************************************/
 
 struct testcase {
-  char *buffer;   /* holds the file data to send to the client */
-  size_t bufsize; /* size of the data in buffer */
-  char *rptr;     /* read pointer into the buffer */
-  size_t rcount;  /* amount of data left to read of the file */
-  long testno;    /* test case number */
-  int ofile;      /* file descriptor for output file when uploading to us */
+  char *buffer;     /* holds the file data to send to the client */
+  size_t bufsize;   /* size of the data in buffer */
+  const char *rptr; /* read pointer into the buffer */
+  size_t rcount;    /* amount of data left to read of the file */
+  long testno;      /* test case number */
+  int ofile;        /* file descriptor for output file when uploading to us */
 
-  int writedelay; /* number of seconds between each packet */
+  int writedelay;   /* number of seconds between each packet */
 };
 
 struct formats {
@@ -454,7 +454,7 @@ static ssize_t write_behind(struct testcase *test, int convert)
     c = *p++;                     /* pick up a character */
     if(prevchar == '\r') {        /* if prev char was cr */
       if(c == '\n')               /* if have cr,lf then just */
-        lseek(test->ofile, -1, SEEK_CUR); /* smash lf on top of the cr */
+        curl_lseek(test->ofile, -1, SEEK_CUR); /* smash lf on top of the cr */
       else if(c == '\0')          /* if have cr,nul then */
         goto skipit;              /* just skip over the putc */
       /* else just fall through and allow it */
@@ -889,7 +889,8 @@ static int do_tftp(struct testcase *test, struct tftphdr *tp, ssize_t size)
   char *cp;
   int first = 1, ecode;
   const struct formats *pf;
-  char *filename, *mode = NULL;
+  const char *filename;
+  char *mode = NULL;
 #ifdef USE_WINSOCK
   DWORD recvtimeout, recvtimeoutbak;
 #endif
@@ -1004,7 +1005,7 @@ static int do_tftp(struct testcase *test, struct tftphdr *tp, ssize_t size)
   return 0;
 }
 
-static int test_tftpd(int argc, char **argv)
+static int test_tftpd(int argc, const char **argv)
 {
   srvr_sockaddr_union_t me;
   struct tftphdr *tp;
